from flask import current_app
from flask_login import current_user
from extensions.ext_database import db
from models.account import Tenant, TenantAccountJoin, TenantAccountJoinRole
from models.provider import Provider

from services.billing_service import BillingService
from services.account_service import TenantService


class WorkspaceService:
    @classmethod
    def get_tenant_info(cls, tenant: Tenant):
        if not tenant:
            return None
        tenant_info = {
            'id': tenant.id,
            'name': tenant.name,
            'plan': tenant.plan,
            'status': tenant.status,
            'created_at': tenant.created_at,
            'providers': [],
            'in_trail': True,
            'trial_end_reason': None,
            'role': 'normal',
        }

        # Get role of user
        tenant_account_join = db.session.query(TenantAccountJoin).filter(
            TenantAccountJoin.tenant_id == tenant.id,
            TenantAccountJoin.account_id == current_user.id
        ).first()
        tenant_info['role'] = tenant_account_join.role

        edition = current_app.config['EDITION']
        if edition == 'CLOUD':
            billing_info = BillingService.get_info(tenant_info['id'])

            if billing_info['can_replace_logo'] and TenantService.has_roles(tenant, [TenantAccountJoinRole.OWNER, TenantAccountJoinRole.ADMIN]):
                tenant_info['custom_config'] = tenant.custom_config_dict

        # Get providers
        providers = db.session.query(Provider).filter(
            Provider.tenant_id == tenant.id
        ).all()

        # Add providers to the tenant info
        tenant_info['providers'] = providers

        return tenant_info
